@@ -78,7 +78,7 @@ relay_address_new_suggestion(const tor_addr_t *suggested_addr,
     /* Do not believe anyone who says our address is their address. */
     log_fn(LOG_PROTOCOL_WARN, LD_PROTOCOL,
            "A relay endpoint %s is telling us that their address is ours.",
-           fmt_addr(peer_addr));
+           safe_str(fmt_addr(peer_addr)));
     return;
   }
 
@@ -212,17 +212,19 @@ relay_addr_learn_from_dirauth(void)
       return;
     }
     const node_t *node = node_get_by_id(rs->identity_digest);
-    if (!node) {
+    extend_info_t *ei = NULL;
+    if (node) {
+      ei = extend_info_from_node(node, 1, false);
+    }
+    if (!node || !ei) {
       /* This can happen if we are still in the early starting stage where no
        * descriptors we actually fetched and thus we have the routerstatus_t
        * for the authority but not its descriptor which is needed to build a
        * circuit and thus learn our address. */
-      log_info(LD_GENERAL, "Can't build a circuit to an authority. Unable to "
-                           "learn for now our address from them.");
-      return;
-    }
-    extend_info_t *ei = extend_info_from_node(node, 1, false);
-    if (BUG(!ei)) {
+      log_info(LD_GENERAL,
+               "Trying to learn our IP address by connecting to an "
+               "authority, but can't build a circuit to one yet. Will try "
+               "again soon.");
       return;
     }
 
