@@ -12,6 +12,7 @@
 #include "lib/cc/torint.h"
 
 #include "lib/metrics/metrics_common.h"
+#include "lib/container/smartlist.h"
 
 #ifdef METRICS_STORE_ENTRY_PRIVATE
 
@@ -37,6 +38,7 @@ struct metrics_store_entry_t {
   union {
     metrics_counter_t counter;
     metrics_gauge_t gauge;
+    metrics_histogram_t histogram;
   } u;
 };
 
@@ -47,7 +49,9 @@ typedef struct metrics_store_entry_t metrics_store_entry_t;
 /* Allocators. */
 metrics_store_entry_t *metrics_store_entry_new(const metrics_type_t type,
                                                const char *name,
-                                               const char *help);
+                                               const char *help,
+                                               size_t bucket_count,
+                                               const int64_t *buckets);
 
 void metrics_store_entry_free_(metrics_store_entry_t *entry);
 #define metrics_store_entry_free(entry) \
@@ -55,8 +59,16 @@ void metrics_store_entry_free_(metrics_store_entry_t *entry);
 
 /* Accessors. */
 int64_t metrics_store_entry_get_value(const metrics_store_entry_t *entry);
+uint64_t metrics_store_hist_entry_get_value(const metrics_store_entry_t *entry,
+                                           const int64_t bucket);
 bool metrics_store_entry_has_label(const metrics_store_entry_t *entry,
                                    const char *label);
+metrics_store_entry_t *metrics_store_find_entry_with_label(
+        const smartlist_t *entries, const char *label);
+bool metrics_store_entry_is_histogram(const metrics_store_entry_t *entry);
+uint64_t metrics_store_hist_entry_get_count(
+        const metrics_store_entry_t *entry);
+int64_t metrics_store_hist_entry_get_sum(const metrics_store_entry_t *entry);
 
 /* Modifiers. */
 void metrics_store_entry_add_label(metrics_store_entry_t *entry,
@@ -64,5 +76,7 @@ void metrics_store_entry_add_label(metrics_store_entry_t *entry,
 void metrics_store_entry_reset(metrics_store_entry_t *entry);
 void metrics_store_entry_update(metrics_store_entry_t *entry,
                                 const int64_t value);
+void metrics_store_hist_entry_update(metrics_store_entry_t *entry,
+                                const int64_t value, const int64_t obs);
 
 #endif /* !defined(TOR_LIB_METRICS_METRICS_STORE_ENTRY_H) */
